summaryrefslogtreecommitdiffstats
path: root/lisp/init-mac.el
diff options
context:
space:
mode:
Diffstat (limited to 'lisp/init-mac.el')
-rw-r--r--lisp/init-mac.el12
1 files changed, 7 insertions, 5 deletions
diff --git a/lisp/init-mac.el b/lisp/init-mac.el
index a5f3965..beedcf2 100644
--- a/lisp/init-mac.el
+++ b/lisp/init-mac.el
@@ -5,12 +5,14 @@
(set-face-attribute 'default nil :family font-family)
(set-face-attribute 'default nil :height 140)
;; fira code at 14 pt may result in (window-total-width) being
;; exactly 160 which makes sensible splitting less sensible
;;
- ;; decrement split-width-threshold so that vertical splits are still
- ;; preferred in most cases
- (setq split-width-threshold (- split-width-threshold 10))))
+ ;; adjust thresholds so that vertical splits are still preferred in most
+ ;; cases
+ (setq split-width-threshold (- split-width-threshold 10))
+ (setq split-height-threshold (+ split-height-threshold 10))))
;; configure modifiers
(setq mac-option-modifier 'super)
@@ -5,12 +5,14 @@
(set-face-attribute 'default nil :family font-family)
(set-face-attribute 'default nil :height 140)
- ;; fira code at 14 pt may result in (window-total-width) being
- ;; exactly 160 which makes sensible splitting less sensible
+ ;; fira code at 14 pt may result in (window-total-width) being exactly 160,
+ ;; or (window-total-height) being exactly 80, which makes sensible splitting
+ ;; less sensible
;;